==> openshift-model-operatorhub-5.7.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorGroupSpecBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecBuilder>{
  public OperatorGroupSpecBuilder() {
    this(false);
  }
  public OperatorGroupSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorGroupSpec(), validationEnabled);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorGroupSpec(), validationEnabled);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance) {
    this(fluent, instance, false);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSelector(instance.getSelector()); 
    fluent.withServiceAccountName(instance.getServiceAccountName()); 
    fluent.withStaticProvidedAPIs(instance.getStaticProvidedAPIs()); 
    fluent.withTargetNamespaces(instance.getTargetNamespaces()); 
    this.validationEnabled = validationEnabled; 
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance) {
    this(instance,false);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withSelector(instance.getSelector()); 
    this.withServiceAccountName(instance.getServiceAccountName()); 
    this.withStaticProvidedAPIs(instance.getStaticProvidedAPIs()); 
    this.withTargetNamespaces(instance.getTargetNamespaces()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec build() {
    OperatorGroupSpec buildable = new OperatorGroupSpec(fluent.getSelector(),fluent.getServiceAccountName(),fluent.getStaticProvidedAPIs(),fluent.getTargetNamespaces());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorGroupSpecBuilder that = (OperatorGroupSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorGroupSpecBuilder extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecBuilder>{
  public OperatorGroupSpecBuilder() {
    this(false);
  }
  public OperatorGroupSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorGroupSpec(), validationEnabled);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorGroupSpec(), validationEnabled);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance) {
    this(fluent, instance, false);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSelector(instance.getSelector()); 
    fluent.withServiceAccountName(instance.getServiceAccountName()); 
    fluent.withStaticProvidedAPIs(instance.getStaticProvidedAPIs()); 
    fluent.withTargetNamespaces(instance.getTargetNamespaces()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance) {
    this(instance,false);
  }
  public OperatorGroupSpecBuilder(io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withSelector(instance.getSelector()); 
    this.withServiceAccountName(instance.getServiceAccountName()); 
    this.withStaticProvidedAPIs(instance.getStaticProvidedAPIs()); 
    this.withTargetNamespaces(instance.getTargetNamespaces()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpec build() {
    OperatorGroupSpec buildable = new OperatorGroupSpec(fluent.getSelector(),fluent.getServiceAccountName(),fluent.getStaticProvidedAPIs(),fluent.getTargetNamespaces());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorGroupSpecBuilder that = (OperatorGroupSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
